ezlog

package module
v1.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 11, 2025 License: AGPL-3.0 Imports: 8 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type LogBuilder

type LogBuilder struct {
	// contains filtered or unexported fields
}

LogBuilder is a builder for the global logger.

func New

func New() *LogBuilder

New creates a new LogBuilder.

func (*LogBuilder) Build

func (b *LogBuilder) Build()

Build builds and configures the zerolog global logger.

func (*LogBuilder) SetTviewCompat

func (b *LogBuilder) SetTviewCompat(tviewCompat bool) *LogBuilder

SetTviewCompat sets the tviewCompat field to true.

func (*LogBuilder) SetWriter

func (b *LogBuilder) SetWriter(writer io.Writer) *LogBuilder

SetWriter sets the writer field to the given writer.

func (*LogBuilder) WithTviewCompat

func (b *LogBuilder) WithTviewCompat() *LogBuilder

WithTviewCompat sets the tviewCompat field to true.

func (*LogBuilder) WithWriter

func (b *LogBuilder) WithWriter(writer io.Writer) *LogBuilder

WithWriter sets the writer field to the given writer.

Directories

Path Synopsis

Jump to